==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PortSelectorFluent.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface PortSelectorFluent<A extends PortSelectorFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.authentication.v1alpha1.PortSelector.Port getPort();
    public me.snowdrop.istio.api.authentication.v1alpha1.PortSelector.Port buildPort();
    public A withPort(me.snowdrop.istio.api.authentication.v1alpha1.PortSelector.Port port);
    public Boolean hasPort();
    public A withNamePort(NamePort namePort);
    public PortSelectorFluent.NamePortNested<A> withNewNamePort();
    public PortSelectorFluent.NamePortNested<A> withNewNamePortLike(NamePort item);
    public A withNewNamePort(String name);
    public A withNumberPort(NumberPort numberPort);
    public PortSelectorFluent.NumberPortNested<A> withNewNumberPort();
    public PortSelectorFluent.NumberPortNested<A> withNewNumberPortLike(NumberPort item);
    public A withNewNumberPort(Integer number);

    public interface NamePortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NamePortFluent<PortSelectorFluent.NamePortNested<N>>{

        
    public N and();    public N endNamePort();
}
    public interface NumberPortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NumberPortFluent<PortSelectorFluent.NumberPortNested<N>>{

        
    public N and();    public N endNumberPort();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/authentication/v1alpha1/PortSelectorFluent.java <==
package me.snowdrop.istio.api.authentication.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface PortSelectorFluent<A extends PortSelectorFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildPort instead.
 * @return The buildable object.
 */
@Deprecated public PortSelector.Port getPort();
    public PortSelector.Port buildPort();
    public A withPort(PortSelector.Port port);
    public Boolean hasPort();
    public A withNamePort(NamePort namePort);
    public PortSelectorFluent.NamePortNested<A> withNewNamePort();
    public PortSelectorFluent.NamePortNested<A> withNewNamePortLike(NamePort item);
    public A withNewNamePort(String name);
    public A withNumberPort(NumberPort numberPort);
    public PortSelectorFluent.NumberPortNested<A> withNewNumberPort();
    public PortSelectorFluent.NumberPortNested<A> withNewNumberPortLike(NumberPort item);
    public A withNewNumberPort(Integer number);

    public interface NamePortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NamePortFluent<PortSelectorFluent.NamePortNested<N>>{

        
    public N and();    public N endNamePort();
}
    public interface NumberPortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,NumberPortFluent<PortSelectorFluent.NumberPortNested<N>>{

        
    public N and();    public N endNumberPort();
}


}
